==> tine20-voip_2019.12.5.tar.bz2: Phone/js/Phone-lang-zh_TW-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Phone **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Phone'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Chinese (Taiwan) (http://www.transifex.com/tine20/tine20/language/zh_TW/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: zh_TW\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Call"
: ""

, "Calls"
: ""

, "Line"
: "分機"

, "Caller Id"
: "來電ID"

, "Start"
: "開始"

, "Connected"
: "已連線"

, "Disconnected"
: "通話完畢"

, "Duration"
: ""

, "Ringing"
: "響鈴中"

, "Direction"
: ""

, "Source"
: "來源"

, "Destination"
: "目的端"

, "Phone"
: ""

, "Phones"
: "電話"

, "Settings"
: ""

, "Lines"
: ""

, "Description"
: ""

, "Number"
: "號碼"

, "Cancel"
: "取消"

, "Dial"
: "撥打"

, "Error"
: "錯誤"

, "Not possible to dial."
: ""

, "Edit phone settings"
: "設定電話簿"

, "Dial number"
: "撥號"

, "Initiate a new outgoing call"
: "啟動新的撥出號碼"

, "No phone selected"
: ""

, "Please select the desired phone in the tree!"
: ""

, "Call contact"
: "撥電話給聯絡人"

, "Work"
: "工作"

, "Home"
: ""

, "Cell"
: ""

, "Cell private"
: ""

, "Incoming call"
: "來電號碼"

, "Outgoing call"
: "撥出號碼"

, "unknown number"
: "未知號碼"

, "local prefix for outgoing calls"
: ""

, "telephone area code"
: ""

, "regex for local calls"
: ""

, "identifies if a calling number is a local call without leading area code"
: ""

, "own telephone number"
: ""

, "own telephone number to prefix to internal calls"
: ""

, "Calls this week"
: ""

, "Incoming and outgoing calls of this week"
: ""

, "Calls last week"
: ""

, "Incoming and outgoing calls of last week"
: ""

, "Calls this month"
: ""

, "Incoming and outgoing calls of this month"
: ""

, "Calls last month"
: ""

, "Incoming and outgoing calls of last month"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-voip_2020.03.4.tar.bz2: Phone/js/Phone-lang-zh_TW-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Phone **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Phone'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Chinese (Taiwan) (http://www.transifex.com/tine20/tine20/language/zh_TW/)\nLanguage: zh_TW\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Incoming call"
: "來電號碼"

, "Outgoing call"
: "撥出號碼"

, "unknown number"
: "未知號碼"

, "Phone"
: ""

, "Line"
: "分機"

, "Number"
: "號碼"

, "Cancel"
: "取消"

, "Dial"
: "撥打"

, "Error"
: "錯誤"

, "Not possible to dial."
: ""

, "Call contact"
: "撥電話給聯絡人"

, "Work"
: "工作"

, "Home"
: ""

, "Cell"
: ""

, "Cell private"
: ""

, "Edit phone settings"
: "設定電話簿"

, "Dial number"
: "撥號"

, "Initiate a new outgoing call"
: "啟動新的撥出號碼"

, "Phones"
: "電話"

, "No phone selected"
: ""

, "Please select the desired phone in the tree!"
: ""

, "Calls this week"
: ""

, "Calls last week"
: ""

, "Calls this month"
: ""

, "Calls last month"
: ""

, "Incoming and outgoing calls of this week"
: ""

, "Incoming and outgoing calls of last week"
: ""

, "Incoming and outgoing calls of this month"
: ""

, "Incoming and outgoing calls of last month"
: ""

, "Local prefix for outgoing calls"
: ""

, "telephone area code"
: ""

, "regex for local calls"
: ""

, "Identifies if a calling number is a local call without leading area code."
: ""

, "own telephone number"
: ""

, "Own telephone number to prefix to internal calls."
: ""

, "Call"
: ""

, "Calls"
: ""

, "Caller Id"
: "來電ID"

, "Start"
: "開始"

, "Connected"
: "已連線"

, "Disconnected"
: "通話完畢"

, "Duration"
: ""

, "Ringing"
: "響鈴中"

, "Direction"
: ""

, "Source"
: "來源"

, "Destination"
: "目的端"

, "resolved destination"
: ""

, "Settings"
: ""

, "Lines"
: ""

, "Description"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
